@@ -2,6 +2,7 @@
 
    Copyright (C) 2005 Dario Massarin <nekkar@libero.it>
    Copyright (C) 2009 Lukas Appelhans <l.appelhans@gmx.de>
+   Copyright (C) 2009 Matthias Fuchs <mat69@gmx.net>
 
    Based on:
        kmainwidget.{h,cpp}
@@ -23,11 +24,12 @@
 #include <KNotification>
 #include <ktabwidget.h>
 
+#include <Solid/Networking>
 #include <QtXml/QDomElement>
 
 #include "kuiserverjobs.h"
 #include "scheduler.h"
-#include "kget_export.h"
+#include "../kget_export.h"
 #include "transfer.h"
 #include "transfergrouphandler.h"
 
@@ -46,8 +48,11 @@ class KGetPlugin;
 class MainWindow;
 class NewTransferDialog;
 class TransferGroupScheduler;
-class KPassivePopup;
+class TransferHistoryStore;
 
+#ifdef HAVE_NEPOMUK
+class NepomukController;
+#endif
 
 /**
  * This is our KGet class. This is where the user's transfers and searches are
@@ -62,12 +67,20 @@ class KPassivePopup;
 class KGET_EXPORT KGet
 {
     friend class NewTransferDialog;
+    friend class NewTransferDialogHandler;
     friend class GenericObserver;
     friend class TransferTreeModel;
+    friend class UrlChecker;
     public:
         enum AfterFinishAction {
             Quit = 0,
-            Shutdown = 1
+            Shutdown = 1,
+            Hibernate = 2,
+            Suspend = 3
+        };
+        enum DeleteMode {
+            AutoDelete,
+            DeleteFiles
         };
         ~KGet();
 
@@ -126,13 +139,13 @@ class KGET_EXPORT KGet
                                              QString groupName = QString(), bool start = false);
 
         /**
-         * Adds a new transfer to the KGet, it is assumed that this takes place because of loading
+         * Adds new transfers to the KGet, it is assumed that this takes place because of loading
          * that results in less checks for loaction etc.
          *
-         * @param e The transfer's dom element
+         * @param elements The dom elements of the transfers to add
          * @param groupName The name of the group the new transfer will belong to
          */
-        static TransferHandler * addTransfer(const QDomElement& e, const QString& groupName = QString());
+        static QList<TransferHandler*> addTransfers(const QList<QDomElement> &elements, const QString &groupName = QString());
 
         /**
          * Adds new transfers to the KGet
@@ -152,7 +165,25 @@ class KGET_EXPORT KGet
          *
          * @param transfer The transfer to be removed
          */
-        static bool delTransfer(TransferHandler * transfer);
+        static bool delTransfer(TransferHandler * transfer, DeleteMode mode = AutoDelete);
+
+        /**
+         * Same as delTransfer, only that files are removed synchronously when possible
+         */
+        static bool delTransferSynchronously(TransferHandler * transfer, DeleteMode mode = AutoDelete);
+
+        /**
+         * Removes multiple transfers from the KGet
+         *
+         * @param transfers The transfers to be removed
+         */
+        static bool delTransfers(const QList<TransferHandler*> &transfers, DeleteMode mode = AutoDelete);
+
+        /**
+         * Same as delTransfers, only that files are removed synchronously when possible
+         * @see delTransfers
+         */
+        static bool delTransfersSynchronously(const QList<TransferHandler*> &transfers, DeleteMode mode = AutoDelete);
 
         /**
          * Moves a transfer to a new group
@@ -182,7 +213,7 @@ class KGET_EXPORT KGet
          * @returns the list of selected groups
          */
         static QList<TransferGroupHandler *>
-        selectedTransferGroups();
+        selectedTransferGroups(bool *mainSelected = 0);
 
         /**
          * @returns a pointer to the TransferTreeModel object
@@ -225,27 +256,25 @@ class KGET_EXPORT KGet
          * @return a pointer to the KActionCollection objects
          */
         static KActionCollection * actionCollection();
-	
-	/**
-	 * if running == true starts the scheduler
-	 * if running == false stops the scheduler
-	 */
-	static void setSchedulerRunning(bool running=true);
 
-       /**
-        * Returns true if the scheduler has running jobs.
-        */
+        /**
+         * if running == true starts the scheduler
+         * if running == false stops the scheduler
+         */
+        static void setSchedulerRunning(bool running=true);
+
+        /**
+         * Returns true if the scheduler has running jobs.
+         */
         static bool schedulerRunning();
 
         /**
-         * Sets the given view to the TransferTreeModel object
+         * true suspends the scheduler, any events that would result in a reschedule are ignored
+         * false wakes up the scheduler, events result in reschedule again
+         * NOTE this is a HACK for cases where the scheduler is the bottleneck, e.g. when stopping
+         * a lot of running transfers, or starting a lot transfers
          */
-        static void addTransferView(QAbstractItemView * view);
-
-        /**
-         * Sets the given comboBox to the TransferTreeModel object
-         */
-        static void addTransferView(KComboBox * view);
+        static void setSuspendScheduler(bool isSuspended);
 
         /**
          * Gets all transfers
@@ -280,19 +309,16 @@ class KGET_EXPORT KGet
          */
         static void settingsChanged();
 
-        /**
-         * Returns the kget kuiserver jobs manager
-         *
-         */
-        static void registerKJob(KJob *);
-        static void unregisterKJob(KJob *);
-        static void reloadKJobs();
-
          /**
           * @return a list of the groups assigned to the filename of a transfer
           */
         static QList<TransferGroupHandler*> groupsFromExceptions(const KUrl &filename);
 
+        /**
+         * Returns true if sourceUrl matches any of the patterns
+         */
+        static bool matchesExceptions(const KUrl &sourceUrl, const QStringList &patterns);
+
         /**
          * Scans for all the available plugins and creates the proper
          * transfer DataSource object for transfers Containers
@@ -339,9 +365,11 @@ class KGET_EXPORT KGet
         * @param text Description of the information showed by the notification
         * @param icon Pixmap showed in the notification, by default 'dialog-error'
         */
-        static void showNotification(QWidget *parent, KNotification::StandardEvent eventId, 
-                                     const QString &text,
-                                     const QString &icon = QString("dialog-error"));
+        static KNotification *showNotification(QWidget *parent, const QString &eventType,
+                                               const QString &text,
+                                               const QString &icon = QString("dialog-error"),
+                                               const QString &title = i18n("KGet"),
+                                               const KNotification::NotificationFlags &flags = KNotification::CloseOnTimeout);
 
         static void loadPlugins();
 
@@ -349,13 +377,19 @@ class KGET_EXPORT KGet
          * Returns a download directory
          * @param preferXDGDownloadDir if true the XDG_DOWNLOAD_DIR will be taken if it is not empty
          * @note depending if the directories exist it will return them in the following order:
-         * (preferXDGDownloadDirectory >) lastDirectory > Desktop > Home
+         * (preferXDGDownloadDirectory >) lastDirectory > XDG_DOWNLOAD_DIR
          */
         static QString generalDestDir(bool preferXDGDownloadDir = false);
 
+#ifdef HAVE_NEPOMUK
+        static NepomukController *nepomukController();
+#endif
+
     private:
         KGet();
 
+        class TransferData;
+
         /**
          * Scans for all the available plugins and creates the proper
          * transfer object for the given src url
@@ -367,6 +401,13 @@ class KGET_EXPORT KGet
          */
         static TransferHandler * createTransfer(const KUrl &src, const KUrl &dest, const QString& groupName = QString(), bool start = false, const QDomElement * e = 0);
 
+        /**
+         * Creates multiple transfers with transferData
+         */
+        static QList<TransferHandler*> createTransfers(const QList<TransferData> &transferData);
+
+        static bool delTransfers(const QList<TransferHandler*> &handlers, bool synchronously, DeleteMode mode = AutoDelete);
+
         static KUrl urlInputDialog();
         static QString destDirInputDialog();
         static KUrl destFileInputDialog(QString destDir = QString(), const QString& suggestedFileName = QString());
@@ -377,9 +418,14 @@ class KGET_EXPORT KGet
         static KUrl getValidDestUrl(const KUrl& destDir, const KUrl &srcUrl);
 
         //Plugin-related functions
-        static void unloadPlugins();
         static KGetPlugin * createPluginFromService( const KService::Ptr &service );
 
+        /**
+         * Stops all downloads if there is no connection and also displays
+         * a message.
+         * If there is a connection, then the downloads will be started again
+         */
+        static void setHasNetworkConnection(bool hasConnection);
 
         /**
          * Deletes the given file, if possible.
@@ -407,6 +453,27 @@ class KGET_EXPORT KGet
 
         //pointer to the kget uiserver jobs manager
         static KUiServerJobs *m_jobManager;
+
+        //pointer to the used TransferHistoryStore
+        static TransferHistoryStore *m_store;
+
+        static bool m_hasConnection;
+
+#ifdef HAVE_NEPOMUK
+        static NepomukController *m_nepomukController;
+#endif
+};
+
+class KGET_EXPORT KGet::TransferData
+{
+    public:
+        TransferData(const KUrl &src, const KUrl &dest, const QString &groupName = QString(), bool start = false, const QDomElement *e = 0);
+
+        KUrl src;
+        KUrl dest;
+        QString groupName;
+        bool start;
+        const QDomElement *e;
 };
 
 class GenericObserver : public QObject
@@ -419,32 +486,28 @@ class GenericObserver : public QObject
     public slots:
         void groupAddedEvent(TransferGroupHandler *handler);
         void groupRemovedEvent(TransferGroupHandler *handler);
-        void transferAddedEvent(TransferHandler *handler, TransferGroupHandler *group);
-        void transferRemovedEvent(TransferHandler *handler, TransferGroupHandler *group);
+        void transfersAddedEvent(const QList<TransferHandler*> &handlers);
+        void transfersRemovedEvent(const QList<TransferHandler*> &handlers);
         void transfersChangedEvent(QMap<TransferHandler*, Transfer::ChangesFlags> transfers);
         void groupsChangedEvent(QMap<TransferGroupHandler*, TransferGroup::ChangesFlags> groups);
         void transferMovedEvent(TransferHandler *, TransferGroupHandler *);
 
     private slots:
         void slotSave();
-#ifdef HAVE_KWORKSPACE
-        void slotShutdown();
-#endif
+        void slotAfterFinishAction();
+        void slotAbortAfterFinishAction();
+        void slotResolveTransferError();
+        void slotNotificationClosed();
+        void slotNetworkStatusChanged(const Solid::Networking::Status &status);
 
     private:
         bool allTransfersFinished();
-        KPassivePopup* popupMessage(const QString &title, const QString &message);
-
-        void checkAndFinish();
-
-#ifdef HAVE_KWORKSPACE
-        void checkAndShutdown();
-#endif
-        void checkAndUpdateSystemTray();
 
         void requestSave();
 
     private:
         QTimer *m_save;
+        QTimer *m_finishAction;
+        QHash<KNotification*, TransferHandler*> m_notifications;
 };
 #endif
