@@ -3,6 +3,7 @@
    Copyright (C) 2002 by Patrick Charbonnier <pch@freeshell.org>
    Based On Caitoo v.0.7.3 (c) 1998 - 2000, Matej Koss
    Copyright (C) 2006 Dario Massarin <nekkar@libero.it>
+   Copyright (C) 2009 - 2010 Matthias Fuchs <mat69@gmx.net>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -75,7 +76,6 @@ private slots:
     void slotNewTransfer();
     void slotImportTransfers();
     void slotExportTransfers();
-    void slotExportPlainTransfers();
     void slotPreferences();
     void slotDeleteGroup();
     void slotRenameGroup();
@@ -92,6 +92,11 @@ private slots:
     void slotTransferGroupSettings();
     void slotTransferSettings();
     void slotCreateMetalink();
+    void slotPriorityTop();
+    void slotPriorityBottom();
+    void slotPriorityUp();
+    void slotPriorityDown();
+    void slotDownloadFinishedActions();
 
     // transfers slots
     void slotStopAllDownload();
@@ -99,6 +104,7 @@ private slots:
     void slotStartAllDownload();
     void slotStartSelectedDownload();
     void slotDeleteSelected();
+    void slotDeleteSelectedIncludingFiles();
     void slotRedownloadSelected();
     void slotTransfersOpenDest();
     void slotTransfersOpenFile();
@@ -121,8 +127,6 @@ private slots:
     void slotGroupsChanged(QMap<TransferGroupHandler*, TransferGroup::ChangesFlags> groups);
 
 private:
-    void exportTransfers(bool plain=false);
-
     /**
     * Returns the completed percents of all active transfers
     */
