@@ -10,9 +10,6 @@
 */
 
 #include "transfermultisegkio.h"
-#ifdef HAVE_NEPOMUK
-#include "core/nepomukhandler.h"
-#endif //HAVE_NEPOMUK
 
 #include "multisegkiosettings.h"
 #include "core/kget.h"
@@ -20,6 +17,7 @@
 // #include "mirrors.h"
 #include "core/filemodel.h"
 #include "core/verifier.h"
+#include "core/signature.h"
 
 #include <kiconloader.h>
 #include <KIO/CopyJob>
@@ -48,28 +46,35 @@ void TransferMultiSegKio::init()
 {
     Transfer::init();
 
-    if (!m_dataSourceFactory)
-    {
-        m_dataSourceFactory = new DataSourceFactory(this, m_dest);
-        connect(m_dataSourceFactory, SIGNAL(speed(ulong)), this, SLOT(slotSpeed(ulong)));
-        connect(m_dataSourceFactory, SIGNAL(percent(ulong)), this, SLOT(slotPercent(ulong)));
-        connect(m_dataSourceFactory, SIGNAL(processedSize(KIO::filesize_t)), this, SLOT(slotProcessedSize(KIO::filesize_t)));
-        connect(m_dataSourceFactory, SIGNAL(statusChanged(Job::Status)), this, SLOT(slotStatus(Job::Status)));
-        connect(m_dataSourceFactory, SIGNAL(totalSize(KIO::filesize_t)), this, SLOT(slotTotalSize(KIO::filesize_t)));
+    if (!m_dataSourceFactory) {
+         m_dataSourceFactory = new DataSourceFactory(this, m_dest);
+        connect(m_dataSourceFactory, SIGNAL(capabilitiesChanged()), this, SLOT(slotUpdateCapabilities()));
+        connect(m_dataSourceFactory, SIGNAL(dataSourceFactoryChange(Transfer::ChangesFlags)), this, SLOT(slotDataSourceFactoryChange(Transfer::ChangesFlags)));
         connect(m_dataSourceFactory->verifier(), SIGNAL(verified(bool)), this, SLOT(slotVerified(bool)));
+        connect(m_dataSourceFactory, SIGNAL(log(QString,Transfer::LogLevel)), this, SLOT(setLog(QString,Transfer::LogLevel)));
 
         m_dataSourceFactory->addMirror(m_source, MultiSegKioSettings::segments());
+
+        slotUpdateCapabilities();
     }
 }
 
-void TransferMultiSegKio::deinit()
+void TransferMultiSegKio::deinit(Transfer::DeleteOptions options)
 {
-    if (status() != Job::Finished)//if the transfer is not finished, we delete the *.part-file
+    if (options & Transfer::DeleteFiles)//if the transfer is not finished, we delete the *.part-file
     {
         m_dataSourceFactory->deinit();
     }//TODO: Ask the user if he/she wants to delete the *.part-file? To discuss (boom1992)
 }
 
+void TransferMultiSegKio::synchronDeinit(Transfer::DeleteOptions options)
+{
+    if (options & Transfer::DeleteFiles)//if the transfer is not finished, we delete the *.part-file
+    {
+        m_dataSourceFactory->synchronDeinit();
+    }//TODO: Ask the user if he/she wants to delete the *.part-file? To discuss (boom1992)
+}
+
 void TransferMultiSegKio::start()
 {
     kDebug(5001) << "Start TransferMultiSegKio";
@@ -88,7 +93,7 @@ void TransferMultiSegKio::start()
 
         TransferDataSource *mirrorSearch = KGet::createTransferDataSource(m_source, element, this);
         if (mirrorSearch) {
-            connect(mirrorSearch, SIGNAL(data(const QList<KUrl>&)), this, SLOT(slotSearchUrls(const QList<KUrl>&)));
+            connect(mirrorSearch, SIGNAL(data(QList<KUrl>)), this, SLOT(slotSearchUrls(QList<KUrl>)));
             mirrorSearch->start();
         }
     }
@@ -107,11 +112,6 @@ void TransferMultiSegKio::stop()
     }
 }
 
-bool TransferMultiSegKio::isResumable() const
-{
-    return true;
-}
-
 bool TransferMultiSegKio::repair(const KUrl &file)
 {
     if (!file.isValid() || (m_dest == file))
@@ -119,6 +119,7 @@ bool TransferMultiSegKio::repair(const KUrl &file)
         if (m_dataSourceFactory && (m_dataSourceFactory->verifier()->status() == Verifier::NotVerified))
         {
             m_dataSourceFactory->repair();
+            return true;
         }
     }
 
@@ -135,7 +136,7 @@ bool TransferMultiSegKio::setDirectory(const KUrl& newDirectory)
 bool TransferMultiSegKio::setNewDestination(const KUrl &newDestination)
 {
     kDebug(5001) << "New destination: " << newDestination;
-    if (/*isResumable() && */newDestination.isValid() && (newDestination != dest()) && m_dataSourceFactory)
+    if (newDestination.isValid() && (newDestination != dest()) && m_dataSourceFactory)
     {
         m_movingFile = true;
         stop();
@@ -148,12 +149,7 @@ bool TransferMultiSegKio::setNewDestination(const KUrl &newDestination)
             m_fileModel->setDirectory(directory());
         }
 
-#ifdef HAVE_NEPOMUK
-        nepomukHandler()->setNewDestination(m_dest);
-#endif //HAVE_NEPOMUK
-
         setTransferChange(Tc_FileName);
-
         return true;
     }
     return false;
@@ -174,16 +170,51 @@ void TransferMultiSegKio::save(const QDomElement &element)
     m_dataSourceFactory->save(element);
 }
 
-void TransferMultiSegKio::slotStatus(Job::Status status)
+void TransferMultiSegKio::slotDataSourceFactoryChange(Transfer::ChangesFlags change)
 {
-    setStatus(status);
-    setTransferChange(Tc_Status, true);
+    if (change & Tc_Status) {
+        setStatus(m_dataSourceFactory->status());
 
-    if (m_fileModel)
-    {
-        QModelIndex statusIndex = m_fileModel->index(m_dest, FileItem::Status);
-        m_fileModel->setData(statusIndex, status);
+        if (m_fileModel) {
+            QModelIndex statusIndex = m_fileModel->index(m_dest, FileItem::Status);
+            m_fileModel->setData(statusIndex, status());
+        }
     }
+    if (change & Tc_TotalSize) {
+        m_totalSize = m_dataSourceFactory->size();
+        if (m_fileModel) {
+            QModelIndex sizeIndex = m_fileModel->index(m_dest, FileItem::Size);
+            m_fileModel->setData(sizeIndex, static_cast<qlonglong>(m_totalSize));
+        }
+    }
+    if (change & Tc_DownloadedSize) {
+        KIO::filesize_t processedSize = m_dataSourceFactory->downloadedSize();
+        //only start the verification search _after_ data has come in, that way only connections
+        //are requested if there is already a successful one
+        if ((processedSize != m_downloadedSize) && !m_verificationSearch && MultiSegKioSettings::useSearchVerification()) {
+            m_verificationSearch = true;
+            QDomDocument doc;
+            QDomElement element = doc.createElement("TransferDataSource");
+            element.setAttribute("type", "checksumsearch");
+            doc.appendChild(element);
+
+            TransferDataSource *checksumSearch = KGet::createTransferDataSource(m_source, element, this);
+            if (checksumSearch) {
+                connect(checksumSearch, SIGNAL(data(QString,QString)), this, SLOT(slotChecksumFound(QString,QString)));
+                checksumSearch->start();
+            }
+        }
+        m_downloadedSize = m_dataSourceFactory->downloadedSize();
+    }
+    if (change & Tc_Percent) {
+        m_percent = m_dataSourceFactory->percent();
+    }
+    if (change & Tc_DownloadSpeed) {
+        kDebug(5001) << "speed:" << m_downloadSpeed;
+        m_downloadSpeed = m_dataSourceFactory->currentSpeed();
+    }
+
+    setTransferChange(change, true);
 }
 
 void TransferMultiSegKio::slotVerified(bool isVerified)
@@ -207,55 +238,6 @@ void TransferMultiSegKio::slotVerified(bool isVerified)
     }
 }
 
-void TransferMultiSegKio::slotPercent(ulong percent)
-{
-    m_percent = percent;
-    setTransferChange(Tc_Percent, true);
-}
-
-void TransferMultiSegKio::slotProcessedSize(KIO::filesize_t processedSize)
-{
-    //only start the verification search _after_ data has come in, that way only connections
-    //are requested if there is already a successful one
-    if ((processedSize != m_downloadedSize) && !m_verificationSearch && MultiSegKioSettings::useSearchVerification()) {
-        m_verificationSearch = true;
-        QDomDocument doc;
-        QDomElement element = doc.createElement("TransferDataSource");
-        element.setAttribute("type", "checksumsearch");
-        doc.appendChild(element);
-
-        TransferDataSource *checksumSearch = KGet::createTransferDataSource(m_source, element, this);
-        if (checksumSearch) {
-            connect(checksumSearch, SIGNAL(data(QString, QString)), this, SLOT(slotChecksumFound(QString, QString)));
-            checksumSearch->start();
-        }
-    }
-
-    m_downloadedSize = processedSize;
-
-    setTransferChange(Tc_DownloadedSize, true);
-}
-
-void TransferMultiSegKio::slotSpeed(unsigned long bytes_per_second)
-{
-    kDebug(5001) << "slotSpeed: " << bytes_per_second;
-
-    m_downloadSpeed = bytes_per_second;
-    setTransferChange(Tc_DownloadSpeed, true);
-}
-
-void TransferMultiSegKio::slotTotalSize(KIO::filesize_t size)
-{
-    m_totalSize = size;
-    setTransferChange(Tc_TotalSize, true);
-
-    if (m_fileModel)
-    {
-        QModelIndex sizeIndex = m_fileModel->index(m_dest, FileItem::Size);
-        m_fileModel->setData(sizeIndex, static_cast<qlonglong>(m_dataSourceFactory->size()));
-    }
-}
-
 void TransferMultiSegKio::slotSearchUrls(const QList<KUrl> &urls)
 {
     kDebug(5001) << "Found " << urls.size() << " urls.";
@@ -268,7 +250,7 @@ void TransferMultiSegKio::slotSearchUrls(const QList<KUrl> &urls)
 
 void TransferMultiSegKio::slotChecksumFound(QString type, QString checksum)
 {
-    m_dataSourceFactory->verifier()->model()->addChecksum(type, checksum);
+    m_dataSourceFactory->verifier()->addChecksum(type, checksum);
 }
 
 QHash<KUrl, QPair<bool, int> > TransferMultiSegKio::availableMirrors(const KUrl &file) const
@@ -305,7 +287,7 @@ FileModel *TransferMultiSegKio::fileModel()
     if (!m_fileModel)
     {
         m_fileModel = new FileModel(QList<KUrl>() << m_dest, m_dest.upUrl(), this);
-        connect(m_fileModel, SIGNAL(rename(KUrl, KUrl)), this, SLOT(slotRename(KUrl,KUrl)));
+        connect(m_fileModel, SIGNAL(rename(KUrl,KUrl)), this, SLOT(slotRename(KUrl,KUrl)));
 
         QModelIndex statusIndex = m_fileModel->index(m_dest, FileItem::Status);
         m_fileModel->setData(statusIndex, m_dataSourceFactory->status());
@@ -313,6 +295,8 @@ FileModel *TransferMultiSegKio::fileModel()
         m_fileModel->setData(sizeIndex, static_cast<qlonglong>(m_dataSourceFactory->size()));
         QModelIndex checksumVerified = m_fileModel->index(m_dest, FileItem::ChecksumVerified);
         m_fileModel->setData(checksumVerified, verifier()->status());
+        QModelIndex signatureVerified = m_fileModel->index(m_dest, FileItem::SignatureVerified);
+        m_fileModel->setData(signatureVerified, signature()->status());
     }
 
     return m_fileModel;
@@ -329,12 +313,14 @@ void TransferMultiSegKio::slotRename(const KUrl &oldUrl, const KUrl &newUrl)
         m_dataSourceFactory->setNewDestination(newUrl);
 
         m_dest = newUrl;
-#ifdef HAVE_NEPOMUK
-        nepomukHandler()->setNewDestination(m_dest);
-#endif //HAVE_NEPOMUK
 
         setTransferChange(Tc_FileName);
     }
 }
 
+void TransferMultiSegKio::slotUpdateCapabilities()
+{
+    setCapabilities(m_dataSourceFactory->capabilities());
+}
+
 #include "transfermultisegkio.moc"
