@@ -157,12 +157,18 @@ void KopeteItemDelegate::paint( QPainter* painter,
 
 		painter->translate( option.rect.topLeft() );
 
+		QPalette::ColorGroup cg = QPalette::Active;
+		if (!(option.state & QStyle::State_Enabled))
+			cg = QPalette::Disabled;
+		else if (!(option.state & QStyle::State_Active))
+			cg = QPalette::Inactive;
+
 		if ( Kopete::AppearanceSettings::self()->greyIdleMetaContacts() && index.data( Kopete::Items::IdleTimeRole ).toInt() > 0 )
 			painter->setPen( Kopete::AppearanceSettings::self()->idleContactColor() ); //apply the appropriate idle color
 		else if ( option.state & QStyle::State_Selected )
-			painter->setPen( option.palette.color( QPalette::Normal, QPalette::HighlightedText ) );
+			painter->setPen( option.palette.color( cg, QPalette::HighlightedText ) );
 		else
-			painter->setPen( option.palette.color( QPalette::Normal, QPalette::Text ) );
+			painter->setPen( option.palette.color( cg, QPalette::Text ) );
 
 		paintItem( layout.layout(), painter, option, index, 0 );
 
@@ -185,6 +191,14 @@ QList<Kopete::Contact*> KopeteItemDelegate::filterContacts( const QList<Kopete::
 	if ( Kopete::AppearanceSettings::self()->showOfflineUsers() )
 		return contacts;
 
+	QAbstractItemView* itemView = qobject_cast<QAbstractItemView*>(parent());
+	if ( itemView )
+	{
+		QSortFilterProxyModel* proxyModel = qobject_cast<QSortFilterProxyModel*>(itemView->model());
+		if ( proxyModel && !proxyModel->filterRegExp().isEmpty() )
+			return contacts;
+	}
+
 	QList<Kopete::Contact*> filtered;
 
 	foreach( Kopete::Contact *contact, contacts )
@@ -375,7 +389,7 @@ void KopeteItemDelegate::paintItem( ContactList::LayoutItemConfig config, QPaint
 					hasFixedTypeItem = true;
 					dlItem.type = LayoutFixed;
 				}
-				else if ( ContactList::LayoutManager::PlaceHolder )
+				else if ( value == ContactList::LayoutManager::PlaceHolder )
 				{
 					dlItem.type = LayoutNormal;
 				}
