@@ -21,6 +21,7 @@
 #include "kopetemetacontact.h"
 #include "kopetemetacontact_p.h"
 
+#include <QTextDocument>
 
 #include <kabc/addressbook.h>
 #include <kabc/addressee.h>
@@ -29,6 +30,7 @@
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kdeversion.h>
+#include <knotification.h>
 
 #include "kabcpersistence.h"
 #include "kopetecontactlist.h"
@@ -40,29 +42,34 @@
 #include "kopetegroup.h"
 #include "kopeteglobal.h"
 #include "kopeteuiglobal.h"
+#include "kopetebehaviorsettings.h"
+#include "kopeteemoticons.h"
 
 namespace Kopete {
 
 MetaContact::MetaContact()
 	: ContactListElement( ContactList::self() ), d(new Private())
 {
-	connect( this, SIGNAL( pluginDataChanged() ), SIGNAL( persistentDataChanged() ) );
-	connect( this, SIGNAL( iconChanged( Kopete::ContactListElement::IconState, const QString & ) ), SIGNAL( persistentDataChanged() ) );
-	connect( this, SIGNAL( useCustomIconChanged( bool ) ), SIGNAL( persistentDataChanged() ) );
-	connect( this, SIGNAL( displayNameChanged( const QString &, const QString & ) ), SIGNAL( persistentDataChanged() ) );
-	connect( this, SIGNAL( movedToGroup( Kopete::MetaContact *, Kopete::Group *, Kopete::Group * ) ), SIGNAL( persistentDataChanged() ) );
-	connect( this, SIGNAL( removedFromGroup( Kopete::MetaContact *, Kopete::Group * ) ), SIGNAL( persistentDataChanged() ) );
-	connect( this, SIGNAL( addedToGroup( Kopete::MetaContact *, Kopete::Group * ) ), SIGNAL( persistentDataChanged() ) );
-	connect( this, SIGNAL( contactAdded( Kopete::Contact * ) ), SIGNAL( persistentDataChanged() ) );
-	connect( this, SIGNAL( contactRemoved( Kopete::Contact * ) ), SIGNAL( persistentDataChanged() ) );
+	d->metaContactId = QUuid::createUuid();
+
+	connect( this, SIGNAL(pluginDataChanged()), SIGNAL(persistentDataChanged()) );
+	connect( this, SIGNAL(iconChanged(Kopete::ContactListElement::IconState,QString)), SIGNAL(persistentDataChanged()) );
+	connect( this, SIGNAL(useCustomIconChanged(bool)), SIGNAL(persistentDataChanged()) );
+	connect( this, SIGNAL(displayNameChanged(QString,QString)), SIGNAL(persistentDataChanged()) );
+	connect( this, SIGNAL(movedToGroup(Kopete::MetaContact*,Kopete::Group*,Kopete::Group*)), SIGNAL(persistentDataChanged()) );
+	connect( this, SIGNAL(removedFromGroup(Kopete::MetaContact*,Kopete::Group*)), SIGNAL(persistentDataChanged()) );
+	connect( this, SIGNAL(addedToGroup(Kopete::MetaContact*,Kopete::Group*)), SIGNAL(persistentDataChanged()) );
+	connect( this, SIGNAL(contactAdded(Kopete::Contact*)), SIGNAL(persistentDataChanged()) );
+	connect( this, SIGNAL(contactRemoved(Kopete::Contact*)), SIGNAL(persistentDataChanged()) );
 
 	// Update the KABC picture when the KDE Address book change.
-	connect(KABCPersistence::self()->addressBook(), SIGNAL(addressBookChanged(AddressBook *)), this, SLOT(slotUpdateAddressBookPicture()));
+	connect(KABCPersistence::self()->addressBook(), SIGNAL(addressBookChanged(AddressBook*)), this, SLOT(slotUpdateAddressBookPicture()));
 
 	// make sure MetaContact is at least in one group
 	addToGroup( Group::topLevel() );
 			 // I'm not sure this is correct -Olivier
 			 // we probably should do the check in groups() instead
+
 }
 
 MetaContact::~MetaContact()
@@ -70,6 +77,16 @@ MetaContact::~MetaContact()
 	delete d;
 }
 
+QUuid MetaContact::metaContactId() const
+{
+	return d->metaContactId;
+}
+
+void MetaContact::setMetaContactId( const QUuid& newUuid)
+{
+	d->metaContactId = newUuid;
+}
+
 void MetaContact::addContact( Contact *c )
 {
 	if( d->contacts.contains( c ) )
@@ -81,18 +98,17 @@ void MetaContact::addContact( Contact *c )
 		const QString oldDisplayName = displayName();
 
 		d->contacts.append( c );
+		connect( c, SIGNAL(onlineStatusChanged(Kopete::Contact*,Kopete::OnlineStatus,Kopete::OnlineStatus)),
+			SLOT(slotContactStatusChanged(Kopete::Contact*,Kopete::OnlineStatus,Kopete::OnlineStatus)) );
 
-		connect( c, SIGNAL( onlineStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & ) ),
-			SLOT( slotContactStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & ) ) );
+		connect( c, SIGNAL(propertyChanged(Kopete::PropertyContainer*,QString,QVariant,QVariant)),
+			this, SLOT(slotPropertyChanged(Kopete::PropertyContainer*,QString,QVariant,QVariant)) ) ;
 
-		connect( c, SIGNAL( propertyChanged( Kopete::PropertyContainer *, const QString &, const QVariant &, const QVariant & ) ),
-			this, SLOT( slotPropertyChanged( Kopete::PropertyContainer *, const QString &, const QVariant &, const QVariant & ) ) ) ;
+		connect( c, SIGNAL(contactDestroyed(Kopete::Contact*)),
+			this, SLOT(slotContactDestroyed(Kopete::Contact*)) );
 
-		connect( c, SIGNAL( contactDestroyed( Kopete::Contact * ) ),
-			this, SLOT( slotContactDestroyed( Kopete::Contact * ) ) );
-
-		connect( c, SIGNAL( idleStateChanged( Kopete::Contact * ) ),
-			this, SIGNAL( contactIdleStateChanged( Kopete::Contact * ) ) );
+		connect( c, SIGNAL(idleStateChanged(Kopete::Contact*)),
+			this, SIGNAL(contactIdleStateChanged(Kopete::Contact*)) );
 
 		emit contactAdded(c);
 
@@ -106,6 +122,9 @@ void MetaContact::addContact( Contact *c )
 			if ( oldDisplayName != newDisplayName )
 			{
 				emit displayNameChanged( oldDisplayName , displayName() );
+				QListIterator<Kopete::Contact *> it( d->contacts );
+				while (  it.hasNext() )
+					( it.next() )->sync(Contact::DisplayNameChanged);
 			}
 			if ( picture().isNull() )
 			{
@@ -139,7 +158,6 @@ void MetaContact::updateOnlineStatus()
 	}
 }
 
-
 void MetaContact::removeContact(Contact *c, bool deleted)
 {
 	if( !d->contacts.contains( c ) )
@@ -155,7 +173,7 @@ void MetaContact::removeContact(Contact *c, bool deleted)
 		QString currDisplayName = displayName();
 
 		d->contacts.removeAll( c );
-		
+
 		// if the contact was a source of property data, clean
 		if (displayNameSourceContact() == c)
 			setDisplayNameSourceContact(0L);
@@ -207,14 +225,14 @@ void MetaContact::removeContact(Contact *c, bool deleted)
 
 		if(!deleted)
 		{  //If this function is tell by slotContactRemoved, c is maybe just a QObject
-			disconnect( c, SIGNAL( onlineStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & ) ),
-				this, SLOT( slotContactStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & ) ) );
-			disconnect( c, SIGNAL( propertyChanged( Kopete::PropertyContainer *, const QString &, const QVariant &, const QVariant & ) ),
-				this, SLOT( slotPropertyChanged( Kopete::PropertyContainer *, const QString &, const QVariant &, const QVariant & ) ) ) ;
-			disconnect( c, SIGNAL( contactDestroyed( Kopete::Contact * ) ),
-				this, SLOT( slotContactDestroyed( Kopete::Contact * ) ) );
-			disconnect( c, SIGNAL( idleStateChanged( Kopete::Contact * ) ),
-				this, SIGNAL( contactIdleStateChanged( Kopete::Contact *) ) );
+			disconnect( c, SIGNAL(onlineStatusChanged(Kopete::Contact*,Kopete::OnlineStatus,Kopete::OnlineStatus)),
+				this, SLOT(slotContactStatusChanged(Kopete::Contact*,Kopete::OnlineStatus,Kopete::OnlineStatus)) );
+			disconnect( c, SIGNAL(propertyChanged(Kopete::PropertyContainer*,QString,QVariant,QVariant)),
+				this, SLOT(slotPropertyChanged(Kopete::PropertyContainer*,QString,QVariant,QVariant)) ) ;
+			disconnect( c, SIGNAL(contactDestroyed(Kopete::Contact*)),
+				this, SLOT(slotContactDestroyed(Kopete::Contact*)) );
+			disconnect( c, SIGNAL(idleStateChanged(Kopete::Contact*)),
+				this, SIGNAL(contactIdleStateChanged(Kopete::Contact*)) );
 
 			kDebug( 14010 ) << "Contact disconnected";
 
@@ -260,8 +278,12 @@ void MetaContact::setDisplayNameSource(PropertySource source)
 	QString oldName = displayName();
 	d->displayNameSource = source;
 	QString newName = displayName();
-	if ( oldName != newName)
+	if ( oldName != newName) {
 		emit displayNameChanged( oldName, newName );
+		QListIterator<Kopete::Contact *> it( d->contacts );
+		while (  it.hasNext() )
+			( it.next() )->sync(Contact::DisplayNameChanged);
+	}
 }
 
 void MetaContact::setDisplayNameSource( const QString &nameSourcePID, const QString &nameSourceAID, const QString &nameSourceCID )
@@ -413,7 +435,7 @@ Contact *MetaContact::execute()
 	return 0L;
 }
 
-unsigned long int MetaContact::idleTime() const
+quint32 MetaContact::idleTime() const
 {
 	unsigned long int time = 0;
 	QListIterator<Contact *> it( d->contacts );
@@ -421,7 +443,7 @@ unsigned long int MetaContact::idleTime() const
 	{
 		Contact *c = it.next();
 		unsigned long int i = c->idleTime();
-		if( c->isOnline() && i < time || time == 0 )
+		if( (c->isOnline() && i < time) || time == 0 )
 		{
 			time = i;
 		}
@@ -443,6 +465,11 @@ QString MetaContact::statusIcon() const
 				return icon( ContactListElement::Away );
 			else
 				return QString::fromUtf8( "user-away" );
+		case OnlineStatus::Busy:
+			if( useCustomIcon() )
+				return icon( ContactListElement::Away ); //Might want to create custom for busy too
+			else
+				return QString::fromUtf8( "user-busy" );
 
 		case OnlineStatus::Unknown:
 			if( useCustomIcon() )
@@ -469,6 +496,8 @@ QString MetaContact::statusString() const
 			return i18n( "Online" );
 		case OnlineStatus::Away:
 			return i18n( "Away" );
+		case OnlineStatus::Busy:
+			return i18n( "Busy" );
 		case OnlineStatus::Offline:
 			return i18n( "Offline" );
 		case OnlineStatus::Unknown:
@@ -487,7 +516,20 @@ bool MetaContact::isOnline() const
 	QListIterator<Contact *> it( d->contacts );
 	while ( it.hasNext() )
 	{
-		if( it.next()->isOnline() )
+		Contact* c = it.next();
+		if( c && c->isOnline() )
+			return true;
+	}
+	return false;
+}
+
+bool MetaContact::isAlwaysVisible() const
+{
+	QListIterator<Contact *> it( d->contacts );
+	while ( it.hasNext() )
+	{
+		Contact* c = it.next();
+		if ( c && c->property( Kopete::Global::Properties::self()->isAlwaysVisible() ).value().toBool() )
 			return true;
 	}
 	return false;
@@ -544,15 +586,29 @@ void MetaContact::sendFile( const KUrl &sourceURL, const QString &altFileName, u
 	contact->sendFile( sourceURL, altFileName, fileSize );
 }
 
-void MetaContact::emitAboutToSave()
+void MetaContact::serialize()
 {
-	emit aboutToSave( this );
+	clearPluginContactData();
+
+	QSet<Kopete::Protocol*> protocolSet;
+	foreach ( Kopete::Contact* c, contacts() )
+	{
+		Kopete::Protocol* protocol = c->protocol();
+		if ( !protocolSet.contains( protocol ) )
+		{
+			protocolSet.insert( protocol );
+			protocol->serialize( this );
+		}
+	}
 }
 
 void MetaContact::slotContactStatusChanged( Contact * c, const OnlineStatus &status, const OnlineStatus &/*oldstatus*/  )
 {
 	updateOnlineStatus();
 	emit contactStatusChanged( c, status );
+
+	if ( c != c->account()->myself() )
+		onlineStatusNotification( c );
 }
 
 void MetaContact::setDisplayName( const QString &name )
@@ -572,10 +628,10 @@ void MetaContact::setDisplayName( const QString &name )
 	{
 		//check if there is another contact with the same display name.
 		//if this is the case, merge them
-		if(!name.isEmpty())
+		if(!this->d->temporary && !name.isEmpty())
 			foreach(MetaContact *m, ContactList::self()->metaContacts())
 		{
-			if( m != this && m->customDisplayName() == name)
+			if( !m->d->temporary && m != this && m->customDisplayName() == name)
 			{
 				//merge
 				while(!m->d->contacts.isEmpty())
@@ -591,12 +647,11 @@ void MetaContact::setDisplayName( const QString &name )
 		const QString old = d->displayName;
 		d->displayName = name;
 
-					emit displayNameChanged( old , name );
+		emit displayNameChanged( old , name );
 		QListIterator<Kopete::Contact *> it( d->contacts );
 		while (  it.hasNext() )
 			( it.next() )->sync(Contact::DisplayNameChanged);
 	}
-
 }
 
 QString MetaContact::customDisplayName() const
@@ -611,8 +666,8 @@ QString MetaContact::displayName() const
 	{
 		// kabc source, try to get from addressbook
 		// if the metacontact has a kabc association
-		if ( !metaContactId().isEmpty() )
-			return nameFromKABC(metaContactId());
+		if ( !kabcId().isEmpty() )
+			return nameFromKABC(kabcId());
 	}
 	else if ( source == SourceContact || d->displayName.isEmpty())
 	{
@@ -676,7 +731,7 @@ KUrl MetaContact::customPhoto() const
 void MetaContact::setPhoto( const KUrl &url )
 {
 	d->photoUrl = url;
-	d->customPicture.setPicture(url.path());
+	d->customPicture.setPicture(url.toLocalFile());
 
 	if ( photoSource() == SourceCustom )
 	{
@@ -773,9 +828,11 @@ void MetaContact::setDisplayNameSourceContact( Contact *contact )
 {
 	Contact *old = d->displayNameSourceContact;
 	d->displayNameSourceContact = contact;
-	if ( displayNameSource() == SourceContact )
-	{
+	if ( displayNameSource() == SourceContact ) {
 		emit displayNameChanged( nameFromContact(old), nameFromContact(contact));
+		QListIterator<Kopete::Contact *> it( d->contacts );
+		while (  it.hasNext() )
+			( it.next() )->sync(Contact::DisplayNameChanged);
 	}
 }
 
@@ -790,7 +847,7 @@ void MetaContact::setPhotoSourceContact( Contact *contact )
 		if ( contact->hasProperty( Kopete::Global::Properties::self()->photo().key() ) )
 		{
 			photoProp = contact->property( Kopete::Global::Properties::self()->photo().key() ).value();
-		
+
 			if(photoProp.canConvert( QVariant::Image ))
 			{
 				d->contactPicture.setPicture( photoProp.value<QImage>() );
@@ -803,7 +860,19 @@ void MetaContact::setPhotoSourceContact( Contact *contact )
 			{
 				d->contactPicture.setPicture(photoProp.toString());
 			}
+			else
+			{
+				d->contactPicture.clear();
+			}
 		}
+		else
+		{
+			d->contactPicture.clear();
+		}
+	}
+	else
+	{
+		d->contactPicture.clear();
 	}
 
 	if ( photoSource() == SourceContact )
@@ -824,6 +893,9 @@ void MetaContact::slotPropertyChanged( PropertyContainer* _subcontact, const QSt
 			if (displayNameSourceContact() == subcontact)
 			{
 				emit displayNameChanged( oldValue.toString(), newValue.toString());
+				QListIterator<Kopete::Contact *> it( d->contacts );
+				while (  it.hasNext() )
+					( it.next() )->sync(Contact::DisplayNameChanged);
 			}
 			else
 			{
@@ -845,17 +917,62 @@ void MetaContact::slotPropertyChanged( PropertyContainer* _subcontact, const QSt
 				// as the current one is null, lets use this new one
 				if (picture().isNull())
 					setPhotoSourceContact(subcontact);
-					
+
 			}
 			else if(photoSourceContact() == subcontact)
 			{
 				if(d->photoSyncedWithKABC)
 					setPhotoSyncedWithKABC(true);
-					
+
 				setPhotoSourceContact(subcontact);
 			}
 		}
 	}
+
+	if ( (key == Kopete::Global::Properties::self()->statusMessage().key() ||
+	     key == Kopete::Global::Properties::self()->statusTitle().key()) && oldValue != newValue )
+	{
+		QString statusText;
+
+		bool allOffline = !this->isOnline();
+		if ( newValue.toString().isEmpty() || ( !subcontact->isOnline() && !allOffline ) )
+		{
+			// try to find a more suitable away message to be displayed when:
+			// -new away message is empty or
+			// -contact who set it is offline and there are contacts online in the metacontact
+			foreach ( Kopete::Contact *c, d->contacts )
+			{
+				QString curStatusText( c->property( key ).value().toString() );
+				if ( ( allOffline || c->isOnline() ) && !curStatusText.isEmpty() )
+				{
+					// display this contact's away message when:
+					// -this contact's away message is not empty and
+					// -this contact is online or there are no contacts online at all
+					statusText = curStatusText;
+					break;
+				}
+			}
+		}
+		else
+		{
+			// just use new away message when:
+			// -new away message is not empty and
+			// -contact who set it is online or there are no contacts online at all
+			statusText = newValue.toString();
+		}
+
+		if ( key == Kopete::Global::Properties::self()->statusMessage().key() )
+			d->statusMessage.setMessage( statusText );
+		else
+			d->statusMessage.setTitle( statusText );
+
+		emit statusMessageChanged( this );
+	}
+
+	// Here we abuse the onlineStatusChanged signal to force the contact list to refresh and hide the
+	// contact if he is offline and his isAlwaysVisible property changed to false
+	if ( key == Kopete::Global::Properties::self()->isAlwaysVisible().key() && oldValue != newValue )
+		emit onlineStatusChanged( this, d->onlineStatus );
 }
 
 void MetaContact::moveToGroup( Group *from, Group *to )
@@ -867,7 +984,11 @@ void MetaContact::moveToGroup( Group *from, Group *to )
 		return;
 	}
 
-	if ( !to || groups().contains( to )  )
+	// Do nothing (same group)
+	if ( from == to )
+		return;
+
+	if ( !to || groups().contains( to ) )
 	{
 		// We're removing, not moving, because 'to' is illegal
 		removeFromGroup( from );
@@ -921,6 +1042,7 @@ void MetaContact::addToGroup( Group *to )
 	if ( d->temporary && to->type() != Group::Temporary )
 		return;
 
+	// FIXME: This breaks copying MC with drag&drop from topLevel group
 	if ( d->groups.contains( Group::topLevel() ) )
 	{
 		d->groups.removeAll( Group::topLevel() );
@@ -956,6 +1078,11 @@ void Kopete::MetaContact::setAddressBookField( Kopete::Plugin * /* p */, const Q
 	d->addressBook[ app ][ key ] = value;
 }
 
+Kopete::StatusMessage MetaContact::statusMessage() const
+{
+	return d->statusMessage;
+}
+
 void MetaContact::slotPluginLoaded( Plugin *p )
 {
 	if( !p )
@@ -968,6 +1095,16 @@ void MetaContact::slotPluginLoaded( Plugin *p )
 	}
 }
 
+void MetaContact::slotProtocolLoaded( Protocol *p )
+{
+	if( !p )
+		return;
+
+	ContactDataList dataList = pluginContactData( p );
+	if ( !dataList.isEmpty() )
+		p->deserializeContactList( this, dataList );
+}
+
 void MetaContact::slotAllPluginsLoaded()
 {
 	// Now that the plugins and subcontacts are loaded, set the source contact.
@@ -978,7 +1115,7 @@ void MetaContact::slotAllPluginsLoaded()
 void MetaContact::slotUpdateAddressBookPicture()
 {
 	KABC::AddressBook* ab = KABCPersistence::self()->addressBook();
-	QString id = metaContactId();
+	QString id = kabcId();
 	if ( !id.isEmpty() && !id.contains(':') )
 	{
 		KABC::Addressee theAddressee = ab->findByUid(id);
@@ -1021,9 +1158,9 @@ void MetaContact::setTemporary( bool isTemporary, Group *group )
 		moveToGroup(temporaryGroup, group ? group : Group::topLevel());
 }
 
-QString MetaContact::metaContactId() const
+QString MetaContact::kabcId() const
 {
-	if(d->metaContactId.isEmpty())
+	if(d->kabcId.isEmpty())
 	{
 		if(d->contacts.isEmpty())
 			return QString();
@@ -1032,12 +1169,12 @@ QString MetaContact::metaContactId() const
 			return QString();
 		return c->protocol()->pluginId()+QString::fromUtf8(":")+c->account()->accountId()+QString::fromUtf8(":") + c->contactId() ;
 	}
-	return d->metaContactId;
+	return d->kabcId;
 }
 
-void MetaContact::setMetaContactId( const QString& newMetaContactId )
+void MetaContact::setKabcId( const QString& newKabcId )
 {
-	if(newMetaContactId == d->metaContactId)
+	if(newKabcId == d->kabcId)
 		return;
 
 	// 1) Check the Id is not already used by another contact
@@ -1049,7 +1186,7 @@ void MetaContact::setMetaContactId( const QString& newMetaContactId )
 
 	// Don't remove IM addresses from kabc if we are changing contacts;
 	// other programs may have written that data and depend on it
-	d->metaContactId = newMetaContactId;
+	d->kabcId = newKabcId;
 	if ( loading() )
 	{
 		slotUpdateAddressBookPicture();
@@ -1094,9 +1231,9 @@ void MetaContact::setPhotoSyncedWithKABC(bool b)
 				return;
 		}
 
-		if ( !d->metaContactId.isEmpty() && !newValue.isNull())
+		if ( !d->kabcId.isEmpty() && !newValue.isNull())
 		{
-			KABC::Addressee theAddressee = KABCPersistence::self()->addressBook()->findByUid( metaContactId() );
+			KABC::Addressee theAddressee = KABCPersistence::self()->addressBook()->findByUid( kabcId() );
 
 			if ( !theAddressee.isEmpty() )
 			{
@@ -1135,6 +1272,101 @@ QList<Contact *> MetaContact::contacts() const
 	return d->contacts;
 }
 
+void MetaContact::onlineStatusNotification( Kopete::Contact * c )
+{
+	// comparing the status of the previous and new preferred contact is the determining factor in deciding to notify
+	Kopete::OnlineStatus newNotifyOnlineStatus;
+
+	Kopete::Contact * pc = preferredContact();
+	if ( pc )
+		newNotifyOnlineStatus = pc->onlineStatus();
+	else // the last child contact has gone offline or otherwise unreachable, so take the changed contact's online status
+		newNotifyOnlineStatus = c->onlineStatus();
+
+	// ensure we are not suppressing notifications, because connecting or disconnected
+	if ( !c->account()->suppressStatusNotification() && c->account()->isConnected()
+	     && c->account()->myself()->onlineStatus().status() != OnlineStatus::Connecting
+	     && (Kopete::BehaviorSettings::self()->enableEventsWhileAway() || !c->account()->isAway()) )
+	{
+		// figure out what's happened
+		enum ChangeType { noChange, noEvent, signedIn, changedStatus, signedOut };
+		ChangeType t = noChange;
+
+		// first, exclude changes due to blocking or subscription changes at the protocol level
+		if ( d->notifyOnlineStatus.status() == Kopete::OnlineStatus::Unknown || newNotifyOnlineStatus.status() == Kopete::OnlineStatus::Unknown )
+		{
+			t = noEvent; // This means the contact's changed from or to unknown - due to a protocol state change, not a contact state change
+		}
+		else
+		{ // we're dealing with a genuine contact state change
+			if ( d->notifyOnlineStatus.status() == Kopete::OnlineStatus::Offline )
+			{
+				if ( newNotifyOnlineStatus.status() != Kopete::OnlineStatus::Offline )
+				{
+					t = signedIn;	// contact has gone from offline to something else, it's a sign-in
+				}
+			}
+			else if ( d->notifyOnlineStatus.isDefinitelyOnline()) //Is that correct?
+			{
+				if ( newNotifyOnlineStatus.status() == Kopete::OnlineStatus::Offline )
+				{
+					t = signedOut;	// contact has gone from an online state to an offline state, it's a sign out
+				}
+				else if ( d->notifyOnlineStatus > newNotifyOnlineStatus || d->notifyOnlineStatus < newNotifyOnlineStatus ) // operator!= is useless because it's an identity operator, not an equivalence operator
+				{
+					// contact has changed online states, it's a status change,
+					// and the preferredContact changed status, or there is a new preferredContacat
+					// so it's worth notifying
+					t = changedStatus;
+				}
+			}
+			else if ( d->notifyOnlineStatus != newNotifyOnlineStatus )
+			{
+				// catch-all for any other status change we don't know about
+				t = noEvent;
+			}
+		}
+
+		// now issue the appropriate notification
+		KNotification *notify = 0;
+		switch ( t )
+		{
+		case noEvent:
+		case noChange:
+			break;
+		case signedIn:
+			notify = new KNotification( QString("kopete_contact_online"), Kopete::UI::Global::mainWidget() );
+			notify->setActions( QStringList( i18nc("@action", "Chat") ) );
+			break;
+		case changedStatus:
+			notify = new KNotification( QString("kopete_contact_status_change"), Kopete::UI::Global::mainWidget() );
+			notify->setActions( QStringList( i18nc("@action", "Chat") ) );
+			break;
+		case signedOut:
+			notify = new KNotification( QString("kopete_contact_offline"), Kopete::UI::Global::mainWidget() );
+			break;
+		}
+
+		if( notify )
+		{
+			QString text = i18n( "<qt><i>%1</i> is now %2.</qt>",
+			                     Kopete::Emoticons::parseEmoticons( Qt::escape( displayName() ) ),
+			                     Qt::escape( c->onlineStatus().description() ) );
+
+			notify->setText( text );
+			notify->setPixmap( QPixmap::fromImage( picture().image() ) );
+			connect( notify, SIGNAL(activated(uint)) , this, SLOT(execute()) );
+
+			notify->addContext( qMakePair( QString::fromLatin1("contact"), metaContactId().toString() ) );
+			foreach( Kopete::Group *g , groups() )
+			{
+				notify->addContext( qMakePair( QString::fromLatin1("group") , QString::number( g->groupId() ) ) );
+			}
+			notify->sendEvent();
+		}
+	}
+	d->notifyOnlineStatus = newNotifyOnlineStatus;
+}
 
 
 } //END namespace Kopete
