@@ -16,16 +16,15 @@
     * (at your option) any later version.                                   *
     *                                                                       *
     *************************************************************************
-    Patched by Francesco Rossi <redsh@email.it> in order to support new 
+    Patched by Francesco Rossi <redsh@email.it> in order to support new
     google translation page layout (13-sept-2007)
 */
 
 #include <qapplication.h>
 #include <qregexp.h>
-#include <q3signal.h>
 #include <qstring.h>
-//Added by qt3to4:
-#include <QByteArray>
+#include <qbytearray.h>
+#include <qmetaobject.h>
 
 #include <kdebug.h>
 #include <kaction.h>
@@ -33,9 +32,9 @@
 #include <kglobal.h>
 #include <kconfig.h>
 #include <kdeversion.h>
-#include <kaboutdata.h>
 #include <kselectaction.h>
 #include <kicon.h>
+#include <kactioncollection.h>
 
 #include "kopetemetacontact.h"
 #include "kopetecontactlist.h"
@@ -46,13 +45,12 @@
 #include "translatordialog.h"
 #include "translatorguiclient.h"
 #include "translatorlanguages.h"
-#include <kactioncollection.h>
+#include "translatorconfig.h"
 
-typedef KGenericFactory<TranslatorPlugin> TranslatorPluginFactory;
-static const KAboutData aboutdata("kopete_translator", 0, ki18n("Translator") , "1.0" );
-K_EXPORT_COMPONENT_FACTORY( kopete_translator, TranslatorPluginFactory( &aboutdata )  )
+K_PLUGIN_FACTORY( TranslatorPluginFactory, registerPlugin<TranslatorPlugin>(); )
+K_EXPORT_PLUGIN( TranslatorPluginFactory( "kopete_translator" ) )
 
-TranslatorPlugin::TranslatorPlugin( QObject *parent, const QStringList & /* args */ )
+TranslatorPlugin::TranslatorPlugin( QObject *parent, const QVariantList & /* args */ )
 : Kopete::Plugin( TranslatorPluginFactory::componentData(), parent )
 {
 	kDebug( 14308 ) ;
@@ -65,38 +63,36 @@ TranslatorPlugin::TranslatorPlugin( QObject *parent, const QStringList & /* args
 
 	m_languages = new TranslatorLanguages;
 
-	connect( Kopete::ChatSessionManager::self(), SIGNAL( aboutToDisplay( Kopete::Message & ) ),
-		this, SLOT( slotIncomingMessage( Kopete::Message & ) ) );
-	connect( Kopete::ChatSessionManager::self(), SIGNAL( aboutToSend( Kopete::Message & ) ),
-		this, SLOT( slotOutgoingMessage( Kopete::Message & ) ) );
-	connect( Kopete::ChatSessionManager::self(), SIGNAL( chatSessionCreated( Kopete::ChatSession * ) ),
-		this, SLOT( slotNewKMM( Kopete::ChatSession * ) ) );
-
-	QStringList keys;
-	QMap<QString, QString> m = m_languages->languagesMap();
-	for ( int k = 0; k <= m_languages->numLanguages(); k++ )
-		keys << m[ m_languages->languageKey( k ) ];
+	connect( Kopete::ChatSessionManager::self(), SIGNAL(aboutToDisplay(Kopete::Message&)),
+		this, SLOT(slotIncomingMessage(Kopete::Message&)) );
+	connect( Kopete::ChatSessionManager::self(), SIGNAL(aboutToSend(Kopete::Message&)),
+		this, SLOT(slotOutgoingMessage(Kopete::Message&)) );
+	connect( Kopete::ChatSessionManager::self(), SIGNAL(chatSessionCreated(Kopete::ChatSession*)),
+		this, SLOT(slotNewKMM(Kopete::ChatSession*)) );
 
 	m_actionLanguage = new KSelectAction( KIcon("preferences-desktop-locale"), i18n( "Set &Language" ), this );
-        actionCollection()->addAction( "contactLanguage", m_actionLanguage );
-	m_actionLanguage->setItems( keys );
-	connect( m_actionLanguage, SIGNAL( triggered(bool) ), this, SLOT(slotSetLanguage() ) );
-	connect( Kopete::ContactList::self(), SIGNAL( metaContactSelected( bool ) ), this, SLOT( slotSelectionChanged( bool ) ) );
+	actionCollection()->addAction( "contactLanguage", m_actionLanguage );
+	connect( m_actionLanguage, SIGNAL(triggered(int)), this, SLOT(slotSetLanguage()) );
+	connect( Kopete::ContactList::self(), SIGNAL(metaContactSelected(bool)), this, SLOT(slotSelectionChanged(bool)) );
 
 	setXMLFile( "translatorui.rc" );
 
 	//Add GUI action to all already existing kmm (if the plugin is launched when kopete already running)
 	const QList<Kopete::ChatSession*> sessions = Kopete::ChatSessionManager::self()->sessions();
 	for (QList<Kopete::ChatSession*>::ConstIterator it= sessions.begin(); it!=sessions.end() ; ++it)
-	  slotNewKMM( *it );
+		slotNewKMM( *it );
 
 	loadSettings();
-	connect( this, SIGNAL( settingsChanged() ), this, SLOT( loadSettings() ) );
+	// When started, contactlist hasn't any selected metacontacts, but this action is available from contactlist
+	// menubar, so we need to disable it.          
+	// It is also important to do it after loadSettings because KSelectAction becomes enabled again after becoming non-empty
+	m_actionLanguage->setEnabled( !Kopete::ContactList::self()->selectedMetaContacts().isEmpty() );
 }
 
 TranslatorPlugin::~TranslatorPlugin()
 {
 	kDebug( 14308 ) ;
+	delete m_languages;
 	pluginStatic_ = 0L;
 }
 
@@ -109,31 +105,43 @@ TranslatorPlugin* TranslatorPlugin::pluginStatic_ = 0L;
 
 void TranslatorPlugin::loadSettings()
 {
+	QString previousLang = m_languages->languageKey( m_service, m_actionLanguage->currentItem() );
+
+	TranslatorConfig::self()->readConfig();
 	int mode = 0;
 
-	KConfigGroup config = KGlobal::config()->group("Translator Plugin");
-	m_myLang = m_languages->languageKey( config.readEntry( "myLang" , 0 ) );
-	m_service = m_languages->serviceKey( config.readEntry( "Service", 0 ) );
+	m_myLang = TranslatorConfig::defaultLanguage();
+	m_service = TranslatorConfig::self()->service();
 
-	if ( config.readEntry( "IncomingDontTranslate", true ) )
-		mode = 0;
-	else if ( config.readEntry( "IncomingShowOriginal", false ) )
-		mode = 1;
-	else if ( config.readEntry( "IncomingTranslate", false ) )
-		mode = 2;
+	if ( TranslatorConfig::incomingDontTranslate() )
+		mode = DontTranslate;
+	else if ( TranslatorConfig::incomingShowOriginal() )
+		mode = ShowOriginal;
+	else if ( TranslatorConfig::incomingTranslate() )
+		mode = JustTranslate;
 
 	m_incomingMode = mode;
 
-	if ( config.readEntry( "OutgoingDontTranslate", true ) )
-		mode = 0;
-	else if ( config.readEntry( "OutgoingShowOriginal", false ) )
-		mode = 1;
-	else if ( config.readEntry( "OutgoingTranslate", false ) )
-		mode = 2;
-	else if ( config.readEntry( "OutgoingAsk", false ) )
-		mode = 3;
+	if ( TranslatorConfig::outgoingDontTranslate() )
+		mode = DontTranslate;
+	else if ( TranslatorConfig::outgoingShowOriginal() )
+		mode = ShowOriginal;
+	else if ( TranslatorConfig::outgoingTranslate() )
+		mode = JustTranslate;
+	else if ( TranslatorConfig::outgoingAsk() )
+		mode = ShowDialog;
 
 	m_outgoingMode = mode;
+
+	// Setting menu entries
+
+	QStringList keys;
+	QMap<QString, QString> m = m_languages->languagesMap( m_service );
+	for ( int k = 0; k <= m_languages->numLanguages( m_service ); k++ )
+		keys << m[ m_languages->languageKey( m_service, k ) ];
+
+	m_actionLanguage->setItems( keys );
+	m_actionLanguage->setCurrentItem( m_languages->languageIndex( m_service, previousLang ) );
 }
 
 void TranslatorPlugin::slotSelectionChanged( bool b )
@@ -147,12 +155,11 @@ void TranslatorPlugin::slotSelectionChanged( bool b )
 
 	if( !m )
 		return;
-
 	QString languageKey = m->pluginData( this, "languageKey" );
 	if ( !languageKey.isEmpty() && languageKey != "null" )
-		m_actionLanguage->setCurrentItem( m_languages->languageIndex( languageKey ) );
+		m_actionLanguage->setCurrentItem( m_languages->languageIndex( m_service, languageKey ) );
 	else
-		m_actionLanguage->setCurrentItem( m_languages->languageIndex( "null" ) );
+		m_actionLanguage->setCurrentItem( m_languages->languageIndex( m_service, "null" ) );
 }
 
 void TranslatorPlugin::slotNewKMM( Kopete::ChatSession *KMM )
@@ -221,16 +228,10 @@ void TranslatorPlugin::slotOutgoingMessage( Kopete::Message &msg )
 
 void TranslatorPlugin::translateMessage( const QString &msg, const QString &from, const QString &to, QObject *obj, const char* slot )
 {
-	Q3Signal completeSignal;
-	completeSignal.connect( obj, slot );
-
 	QString result = translateMessage( msg, from, to );
 
 	if(!result.isNull())
-	{
-		completeSignal.setValue( result );
-		completeSignal.activate();
-	}
+		QMetaObject::invokeMethod( obj, slot, Q_ARG( QString, result ) );
 }
 
 QString TranslatorPlugin::translateMessage( const QString &msg, const QString &from, const QString &to )
@@ -259,16 +260,9 @@ QString TranslatorPlugin::translateMessage( const QString &msg, const QString &f
 
 QString TranslatorPlugin::googleTranslateMessage( const QString &msg, const QString &from, const QString &to )
 {
-	KUrl translatorURL ( "http://translate.google.com/translate_t");
-
-	QString body = QString(QUrl::toPercentEncoding( msg ));
-	QString lp = from + '|' + to;
-
-	QByteArray postData = QString( "text=" + body + "&langpair=" + lp ).toUtf8();
-
-	QString gurl = "http://translate.google.com/translate_t?text=" + body +"&langpair=" + lp;
-	kDebug(14308) << " URL: " << gurl;
-	KUrl geturl ( gurl );
+	KUrl geturl ( QString("http://ajax.googleapis.com/ajax/services/language/translate?v=1.0&q=%1&langpair=%2|%3")
+			.arg(QUrl::toPercentEncoding( msg ), from, to) );
+	kDebug(14308) << "URL:" << geturl;
 
 	KIO::TransferJob *job = KIO::get( geturl );
 	//job = KIO::http_post( translatorURL, postData );
@@ -276,45 +270,8 @@ QString TranslatorPlugin::googleTranslateMessage( const QString &msg, const QStr
 	//job->addMetaData( "content-type", "application/x-www-form-urlencoded" );
 	//job->addMetaData( "referrer", "http://www.google.com" );
 
-	QObject::connect( job, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( slotDataReceived( KIO::Job *, const QByteArray & ) ) );
-	QObject::connect( job, SIGNAL( result( KJob * ) ), this, SLOT( slotJobDone( KJob * ) ) );
-
-	// KIO is async and we use a sync API, so use the processEvents hack to work around that
-	// FIXME: We need to make the libkopete API async to get rid of this processEvents.
-	//        It often causes crashes in the code. - Martijn
-	while ( !m_completed[ job ] )
-		qApp->processEvents();
-
-	QString data = QString::fromLatin1( m_data[ job ] );
-
-	// After hacks, we need to clean
-	m_data.remove( job );
-	m_completed.remove( job );
-
-//	kDebug( 14308 ) << "Google response:"<< endl << data;
-
-//	QRegExp re( "<textarea name=q rows=5 cols=45 wrap=PHYSICAL>(.*)</textarea>" );
-	QRegExp re( "<textarea name=utrans wrap=PHYSICAL dilr=ltr rows=5 id=suggestion>(.*)</textarea>");
-  
-	re.setMinimal( true );
-	re.indexIn( data );
-
-	return re.cap( 1 );
-}
-
-QString TranslatorPlugin::babelTranslateMessage( const QString &msg, const QString &from, const QString &to )
-{
-	QString body = QString(QUrl::toPercentEncoding( msg));
-	QString lp = from + '_' + to;
-	QString gurl = "http://babelfish.yahoo.com/translate_txt?&lp=" + lp  + "&text=" + body;
-	KUrl geturl ( gurl );
-
-	kDebug( 14308 ) << "URL: " << gurl;
-
-	KIO::TransferJob *job = KIO::get( geturl );
-
-	QObject::connect( job, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( slotDataReceived( KIO::Job *, const QByteArray & ) ) );
-	QObject::connect( job, SIGNAL( result( KJob * ) ), this, SLOT( slotJobDone( KJob * ) ) );
+	QObject::connect( job, SIGNAL(data(KIO::Job*,QByteArray)), this, SLOT(slotDataReceived(KIO::Job*,QByteArray)) );
+	QObject::connect( job, SIGNAL(result(KJob*)), this, SLOT(slotJobDone(KJob*)) );
 
 	// KIO is async and we use a sync API, so use the processEvents hack to work around that
 	// FIXME: We need to make the libkopete API async to get rid of this processEvents.
@@ -328,9 +285,50 @@ QString TranslatorPlugin::babelTranslateMessage( const QString &msg, const QStri
 	m_data.remove( job );
 	m_completed.remove( job );
 
-	//kDebug( 14308 ) << "Babelfish response: " << endl << data;
+//	kDebug( 14308 ) << "Google response:"<< endl << data;
 
-	QRegExp re( "<div style=padding:10px;>(.*)</div>" );
+	QRegExp re( "\"translatedText\":\"(.*)\"" );
+
+	re.setMinimal( true );
+	re.indexIn( data );
+
+	return re.cap( 1 );
+}
+
+QString TranslatorPlugin::babelTranslateMessage( const QString &msg, const QString &from, const QString &to )
+{
+	KUrl geturl ( "http://babelfish.yahoo.com/translate_txt" );
+
+	QString body = QUrl::toPercentEncoding( msg );
+	body.replace("%20", "+");
+
+	QByteArray postData = QString( "ei=UTF-8&doit=done&fr=bf-res&intl=1&tt=urltext&trtext=%1&lp=%2_%3&btnTrTxt=Translate")
+				.arg( body, from, to )
+				.toLocal8Bit();
+	kDebug(14308) << "URL:" << geturl << "(post data" << postData << ")";
+
+	KIO::TransferJob *job = KIO::http_post( geturl, postData );
+	job->addMetaData( "content-type", "Content-Type: application/x-www-form-urlencoded" );
+	job->addMetaData( "referrer", "http://babelfish.yahoo.com/translate_txt" );
+
+	QObject::connect( job, SIGNAL(data(KIO::Job*,QByteArray)), this, SLOT(slotDataReceived(KIO::Job*,QByteArray)) );
+	QObject::connect( job, SIGNAL(result(KJob*)), this, SLOT(slotJobDone(KJob*)) );
+
+	// KIO is async and we use a sync API, so use the processEvents hack to work around that
+	// FIXME: We need to make the libkopete API async to get rid of this processEvents.
+	//        It often causes crashes in the code. - Martijn
+	while ( !m_completed[ job ] )
+		qApp->processEvents();
+
+	QString data = QString::fromUtf8( m_data[ job ] );
+
+	// After hacks, we need to clean
+	m_data.remove( job );
+	m_completed.remove( job );
+
+//	kDebug( 14308 ) << "Babelfish response: " << endl << data;
+
+	QRegExp re( "<div style=\"padding:0.6em;\">(.*)</div>" );
 	re.setMinimal( true );
 	re.indexIn( data );
 
@@ -370,8 +368,8 @@ void TranslatorPlugin::sendTranslation( Kopete::Message &msg, const QString &tra
 	case ShowOriginal:
 		if ( msg.format() & Qt::PlainText )
 			msg.setPlainBody( i18n( "%2 \nAuto Translated: \n%1", translated, msg.plainBody() ) );
-		else 
-			msg.setHtmlBody( i18n( "%2 \nAuto Translated: \n%1", translated, msg.plainBody() ) );
+		else
+			msg.setHtmlBody( i18n( "%2 <br/>Auto Translated: <br/>%1", translated, msg.plainBody() ) );
 		break;
 	case ShowDialog:
 	{
@@ -379,7 +377,7 @@ void TranslatorPlugin::sendTranslation( Kopete::Message &msg, const QString &tra
 		d->exec();
 		if ( msg.format() & Qt::PlainText )
 			msg.setPlainBody (d->translatedText() );
-		else	
+		else
 			msg.setHtmlBody( d->translatedText() );
 		delete d;
 		break;
@@ -393,22 +391,22 @@ void TranslatorPlugin::sendTranslation( Kopete::Message &msg, const QString &tra
 
 void TranslatorPlugin::slotDataReceived ( KIO::Job *job, const QByteArray &data )
 {
-	m_data[ job ] += QByteArray( data, data.size() + 1 );
+	m_data[ job ].append(data);
 }
 
 void TranslatorPlugin::slotJobDone ( KJob *job )
 {
 	KIO::Job *kioJob = static_cast<KIO::Job*>(job);
 	m_completed[ kioJob ] = true;
-	QObject::disconnect( kioJob, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( slotDataReceived( KIO::Job *, const QByteArray & ) ) );
-	QObject::disconnect( kioJob, SIGNAL( result( KJob * ) ), this, SLOT( slotJobDone( KJob * ) ) );
+	QObject::disconnect( kioJob, SIGNAL(data(KIO::Job*,QByteArray)), this, SLOT(slotDataReceived(KIO::Job*,QByteArray)) );
+	QObject::disconnect( kioJob, SIGNAL(result(KJob*)), this, SLOT(slotJobDone(KJob*)) );
 }
 
 void TranslatorPlugin::slotSetLanguage()
 {
 	Kopete::MetaContact *m = Kopete::ContactList::self()->selectedMetaContacts().first();
 	if( m && m_actionLanguage )
-		m->setPluginData( this, "languageKey", m_languages->languageKey( m_actionLanguage->currentItem() ) );
+		m->setPluginData( this, "languageKey", m_languages->languageKey( m_service, m_actionLanguage->currentItem() ) );
 }
 
 #include "translatorplugin.moc"
