@@ -180,24 +180,24 @@ void UserDetails::parseCapabilities( Buffer &inbuf, int &xStatus )
 		bool found = false;
 		Guid cap( inbuf.getGuid() );
 		int i;
-		for ( i=0; i < CAP_LAST; i++ )
+		for ( i=0; i < CAP_LAST; ++i )
 		{
-			if ( i == CAP_KOPETE && cap.isEqual ( oscar_caps[i], 12 )   ||
-			   i == CAP_MIRANDA && cap.isEqual ( oscar_caps[i], 8 )     ||
-			   i == CAP_QIP && cap.isEqual ( oscar_caps[i], 16 )        ||
-			   i == CAP_QIPINFIUM && cap.isEqual ( oscar_caps[i], 16 )  ||
-			   i == CAP_QIPPDA && cap.isEqual ( oscar_caps[i], 16 )     ||
-			   i == CAP_QIPSYMBIAN && cap.isEqual ( oscar_caps[i], 16 ) ||
-			   i == CAP_QIPMOBILE && cap.isEqual ( oscar_caps[i], 16 )  ||
-			   i == CAP_JIMM && cap.isEqual ( oscar_caps[i], 5 )        ||
-			   i == CAP_MICQ && cap.isEqual ( oscar_caps[i], 12 )       ||
-			   i == CAP_SIMNEW && cap.isEqual ( oscar_caps[i], 12 )     ||
-			   i == CAP_SIMOLD && cap.isEqual ( oscar_caps[i], 15 )     ||
-			   i == CAP_VMICQ && cap.isEqual ( oscar_caps[i], 6 )       ||
-			   i == CAP_LICQ && cap.isEqual ( oscar_caps[i], 12 )       ||
-			   i == CAP_ANDRQ && cap.isEqual ( oscar_caps[i], 9 )       ||
-			   i == CAP_RANDQ && cap.isEqual ( oscar_caps[i], 9 )       ||
-			     i == CAP_MCHAT && cap.isEqual ( oscar_caps[i], 10 ) )
+			if ( (i == CAP_KOPETE && cap.isEqual ( oscar_caps[i], 12 ) )    ||
+			     (i == CAP_MIRANDA && cap.isEqual ( oscar_caps[i], 8 ) )    ||
+			     (i == CAP_QIP && cap.isEqual ( oscar_caps[i], 16 ) )       ||
+			     (i == CAP_QIPINFIUM && cap.isEqual ( oscar_caps[i], 16 ) ) ||
+			     (i == CAP_QIPPDA && cap.isEqual ( oscar_caps[i], 16 ) )    ||
+			     (i == CAP_QIPSYMBIAN && cap.isEqual ( oscar_caps[i], 16 ) )||
+			     (i == CAP_QIPMOBILE && cap.isEqual ( oscar_caps[i], 16 ) ) ||
+			     (i == CAP_JIMM && cap.isEqual ( oscar_caps[i], 5 ) )       ||
+			     (i == CAP_MICQ && cap.isEqual ( oscar_caps[i], 12 ) )      ||
+			     (i == CAP_SIMNEW && cap.isEqual ( oscar_caps[i], 12 ) )    ||
+			     (i == CAP_SIMOLD && cap.isEqual ( oscar_caps[i], 15 ) )    ||
+			     (i == CAP_VMICQ && cap.isEqual ( oscar_caps[i], 6 ) )      ||
+			     (i == CAP_LICQ && cap.isEqual ( oscar_caps[i], 12 ) )      ||
+			     (i == CAP_ANDRQ && cap.isEqual ( oscar_caps[i], 9 ) )      ||
+			     (i == CAP_RANDQ && cap.isEqual ( oscar_caps[i], 9 ) )      ||
+			     (i == CAP_MCHAT && cap.isEqual ( oscar_caps[i], 10 ) ) )
 			{
 				m_capabilities[i] = true;
 				dbgCaps += capName(i);
@@ -215,7 +215,7 @@ void UserDetails::parseCapabilities( Buffer &inbuf, int &xStatus )
 		}
 		if(!found && xStatus == -1)
 		{
-			for(i = 0; i < XSTAT_LAST; i++)
+			for(i = 0; i < XSTAT_LAST; ++i)
 			{
 				if(oscar_xStatus[i] == cap)
 				{
@@ -367,7 +367,7 @@ void UserDetails::fill( Buffer * buffer )
 				while ( b.bytesAvailable() > 0 )
 				{
 #ifdef OSCAR_USERINFO_DEBUG
-					kDebug(OSCAR_RAW_DEBUG) << "Icon and available message info";
+					kDebug(OSCAR_RAW_DEBUG) << "Icon and status message info";
 #endif
 					Oscar::WORD type2 = b.getWord();
 					Oscar::BYTE number = b.getByte();
@@ -401,13 +401,14 @@ void UserDetails::fill( Buffer * buffer )
 					case 0x0002:
 						if ( length > 0 )
 						{
-							QByteArray personalMessageData = b.getBSTR();
+							Buffer pmBuffer( b.getBBlock( length ) );
+							QByteArray personalMessageData = pmBuffer.getBSTR();
 							
 							QTextCodec *codec = 0;
-							if ( b.bytesAvailable() >= 4 && b.getWord() == 0x0001 )
+							if ( pmBuffer.bytesAvailable() >= 4 && pmBuffer.getWord() == 0x0001 )
 							{
-								b.skipBytes( 2 );
-								QByteArray encoding = b.getBSTR();
+								pmBuffer.skipBytes( 2 );
+								QByteArray encoding = pmBuffer.getBSTR();
 								codec = QTextCodec::codecForName( encoding );
 								kDebug(OSCAR_RAW_DEBUG) << "Encoding:" << encoding;
 							}
@@ -422,7 +423,7 @@ void UserDetails::fill( Buffer * buffer )
 #endif
 						}
 						else
-							kDebug(OSCAR_RAW_DEBUG) << "not enough bytes for available message";
+							kDebug(OSCAR_RAW_DEBUG) << "not enough bytes for status message";
 						break;
 					case 0x000E:
 						if ( length > 0 )
